==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/bg-BG/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Този потребител може да се логне',
    'activated_disabled_help_text' => 'Не можете да редактирате статуса на активация на собствения си профил.',
    'assets_user'       => 'Активи предадени на :name',
    'bulk_update_warn'	=> 'На път сте да редактирате свойствата на :user_count потребители. Моля обърнете внимание, че не можете да променяте собствените си атрибути използвайки този формуляр и трябва да нанесете промени към собствения си потребителски профил индивидуално.',
    'bulk_update_help'	=> 'Този формуляр ви позволява да обновявате няколко потребителски профила едновременно. Попълнете единствено полетата, които желаете да промените. Всички празни полета няма да бъдат променени.',
    'current_assets'    => 'Активи, отписани към този потребител в момента',
    'clone'             => 'Копиране на потребител',
    'contact_user'      => 'Връзка :name',
    'edit'              => 'Редактиране на потребител',
    'filetype_info'     => 'Позволените типове файлове са png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, и rar.',
    'history_user'      => 'История за :name',
    'info'				=> 'Информация',
    'restore_user'		=> 'Кликнете тук, за да ги възстановите.',
    'last_login'        => 'Последен достъп до системата',
    'ldap_config_text'  => 'LDAP конфигурационните настройки могат да бъдат намерени в  Admin > Settings. Избраното (по изобр) местоположение ще бъде настроено за всички въведени потребители.',
    'print_assigned'    => 'Печат на всички отдадени',
    'email_assigned'    => 'Изпрати Е-майл списък на всички заведени активи',
    'user_notified'     => 'На потребителя беше изпратен списак по е-майл с неговите заведени активи.',
    'auto_assign_label' => 'Включи този потребител при автоматичното асоцииране на лицензи',
    'auto_assign_help'  => 'Не включвай този потребител при автоматичното асоцииране на лицензи',
    'software_user'     => 'Софтуерни продукти, изписани на :name',
    'send_email_help'   => 'Трябва да предоставите е-майл адрес за този потребител за да му се изпратят името и паролата. Изпращането на име и парола може да стане при създаването на потребителя. Паролите се съхраняват криптирани и не могат да се възстановят.',
    'view_user'         => 'Преглед на потребител :name',
    'usercsv'           => 'CSV файл',
    'two_factor_admin_optin_help' => 'Текущите настройки на администратор позволяват избирателно прилагане на двуфакторова автентификация. ',
    'two_factor_enrolled' => '2FA устройство записано ',
    'two_factor_active'   => '2FA Активно ',
    'user_deactivated'  => 'Потребителя не може да се впише',
    'user_activated'  => 'Потребителя може да се впише',
    'activation_status_warning' => 'Не променяй статуса на активиране',
    'group_memberships_helpblock' => 'Само админ може да редактира членовете на групата.',
    'superadmin_permission_warning' => 'Само админ може да даде администраторски достъп на потребител.',
    'admin_permission_warning' => 'Само потребители с административни права може да дадат админ достъп.',
    'remove_group_memberships' => 'Премахни членовете на групата',
    'warning_deletion_information' => 'Вие ще заведете всички активи от :count потребител(и) от списъка по-долу. Администраторските имена са оцветени в червено.',
    'update_user_assets_status' => 'Обнови всички активи за следните потребители към този статус',
    'checkin_user_properties' => 'Впиши всички асоцирани настройки към тези потребители',
    'remote_label'   => 'Това е отдалечен потребител',
    'remote'   => 'Отдалечен',
    'remote_help' => 'Това може да бъде използвано, за да филтирате отдалечените потребители които никога или рядко идват на работа.',
    'not_remote_label' => 'Това не е отдалечен потребител',
    'vip_label' => 'ВИП потребител',
    'vip_help' => 'Това може да е полезно да маркиране важните потребители във вашата фирма, ако трябва да ги третирате по особен начин.',
    'create_user' => 'Нов потребител',
    'create_user_page_explanation' => 'Това е акаунт информацията, която ще използвате за достъп до страницата за първи път.',
    'email_credentials' => 'Е-майл достъп',
    'email_credentials_text' => 'Изпрати ми паролата за достъп по е-майл на адреса по-горе',
    'next_save_user' => 'Следва: Запазване на потребител',
    'all_assigned_list_generation' => 'Генерирано на:',
    'email_user_creds_on_create' => 'Да се изпрати ли е-майл с паролата на потребителя?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/bg-BG/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Този потребител може да се логне',
    'activated_disabled_help_text' => 'Не можете да редактирате статуса на активация на собствения си профил.',
    'assets_user'       => 'Активи предадени на :name',
    'bulk_update_warn'	=> 'На път сте да редактирате свойствата на :user_count потребители. Моля обърнете внимание, че не можете да променяте собствените си атрибути използвайки този формуляр и трябва да нанесете промени към собствения си потребителски профил индивидуално.',
    'bulk_update_help'	=> 'Този формуляр ви позволява да обновявате няколко потребителски профила едновременно. Попълнете единствено полетата, които желаете да промените. Всички празни полета няма да бъдат променени.',
    'current_assets'    => 'Активи, отписани към този потребител в момента',
    'clone'             => 'Копиране на потребител',
    'contact_user'      => 'Връзка :name',
    'edit'              => 'Редактиране на потребител',
    'filetype_info'     => 'Позволените типове файлове са png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, и rar.',
    'history_user'      => 'История за :name',
    'info'				=> 'Информация',
    'restore_user'		=> 'Кликнете тук, за да ги възстановите.',
    'last_login'        => 'Последен достъп до системата',
    'ldap_config_text'  => 'LDAP конфигурационните настройки могат да бъдат намерени в  Admin > Settings. Избраното (по изобр) местоположение ще бъде настроено за всички въведени потребители.',
    'print_assigned'    => 'Печат на всички отдадени',
    'email_assigned'    => 'Изпрати Е-майл списък на всички заведени активи',
    'user_notified'     => 'На потребителя беше изпратен списак по е-майл с неговите заведени активи.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Включи този потребител при автоматичното асоцииране на лицензи',
    'auto_assign_help'  => 'Не включвай този потребител при автоматичното асоцииране на лицензи',
    'software_user'     => 'Софтуерни продукти, изписани на :name',
    'send_email_help'   => 'Трябва да предоставите е-майл адрес за този потребител за да му се изпратят името и паролата. Изпращането на име и парола може да стане при създаването на потребителя. Паролите се съхраняват криптирани и не могат да се възстановят.',
    'view_user'         => 'Преглед на потребител :name',
    'usercsv'           => 'CSV файл',
    'two_factor_admin_optin_help' => 'Текущите настройки на администратор позволяват избирателно прилагане на двуфакторова автентификация. ',
    'two_factor_enrolled' => '2FA устройство записано ',
    'two_factor_active'   => '2FA Активно ',
    'user_deactivated'  => 'Потребителя не може да се впише',
    'user_activated'  => 'Потребителя може да се впише',
    'activation_status_warning' => 'Не променяй статуса на активиране',
    'group_memberships_helpblock' => 'Само админ може да редактира членовете на групата.',
    'superadmin_permission_warning' => 'Само админ може да даде администраторски достъп на потребител.',
    'admin_permission_warning' => 'Само потребители с административни права може да дадат админ достъп.',
    'remove_group_memberships' => 'Премахни членовете на групата',
    'warning_deletion_information' => 'Вие ще заведете всички активи от :count потребител(и) от списъка по-долу. Администраторските имена са оцветени в червено.',
    'update_user_assets_status' => 'Обнови всички активи за следните потребители към този статус',
    'checkin_user_properties' => 'Впиши всички асоцирани настройки към тези потребители',
    'remote_label'   => 'Това е отдалечен потребител',
    'remote'   => 'Отдалечен',
    'remote_help' => 'Това може да бъде използвано, за да филтирате отдалечените потребители които никога или рядко идват на работа.',
    'not_remote_label' => 'Това не е отдалечен потребител',
    'vip_label' => 'ВИП потребител',
    'vip_help' => 'Това може да е полезно да маркиране важните потребители във вашата фирма, ако трябва да ги третирате по особен начин.',
    'create_user' => 'Нов потребител',
    'create_user_page_explanation' => 'Това е акаунт информацията, която ще използвате за достъп до страницата за първи път.',
    'email_credentials' => 'Е-майл достъп',
    'email_credentials_text' => 'Изпрати ми паролата за достъп по е-майл на адреса по-горе',
    'next_save_user' => 'Следва: Запазване на потребител',
    'all_assigned_list_generation' => 'Генерирано на:',
    'email_user_creds_on_create' => 'Да се изпрати ли е-майл с паролата на потребителя?',
];
